bridge
library
Classes
-
MActivityAlert
-
An optional alert shown on the Lock Screen and Dynamic Island when a Live
Activity is updated.
-
MosaicBridge
-
-
MosaicLiveActivities
-
Flutter-side API for the iOS Live Activities lifecycle.
-
MosaicPushToken
-
A per-activity APNs push token surfaced from iOS ActivityKit.
-
MosaicTv
-
Android TV / Google TV home-screen channels.
-
MosaicTvProgram
-
One card in an Android TV home-screen channel.
-
MosaicWidgetInfo
-
A bridge to communicate with native home widgets.
A widget the user has placed on their home screen.