MActivityAlert class
An optional alert shown on the Lock Screen and Dynamic Island when a Live Activity is updated.
Constructors
- MActivityAlert({required String title, required String body})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited