MAlignment enum

Where a child sits inside its parent's box.

Inheritance
Available extensions

Values

topStart → const MAlignment
topCenter → const MAlignment
topEnd → const MAlignment
centerStart → const MAlignment
center → const MAlignment
centerEnd → const MAlignment
bottomStart → const MAlignment
bottomCenter → const MAlignment
bottomEnd → const MAlignment

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MAlignment>
A constant List of the values in this enum, in order of their declaration.