MColumn class
Constructors
-
MColumn(List<
MNode> children, {MMainAxisAlignment mainAxisAlignment = MMainAxisAlignment.start, MCrossAxisAlignment crossAxisAlignment = MCrossAxisAlignment.center}) -
const
Properties
-
children
→ List<
MNode> -
final
- crossAxisAlignment → MCrossAxisAlignment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAxisAlignment → MMainAxisAlignment
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited