MDivider class

Divider line (horizontal by default, optionally vertical).

Inheritance

Constructors

MDivider({double thickness = 1, MColor? color, bool vertical = false, double indent = 0})
const

Properties

color MColor?
final
hashCode int
The hash code for this object.
no setterinherited
indent double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
final
vertical bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited