MDynamicIsland class
Dynamic Island presentation regions.
Constructors
- MDynamicIsland({required MNode compactLeading, required MNode compactTrailing, required MNode minimal, required MExpanded expanded})
-
const
Properties
- compactLeading → MNode
-
final
- compactTrailing → MNode
-
final
- expanded → MExpanded
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimal → MNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited