MExpanded class

The expanded Dynamic Island layout slots.

Constructors

MExpanded({MNode? leading, MNode? trailing, MNode? center, MNode? bottom})
const

Properties

bottom MNode?
final
center MNode?
final
hashCode int
The hash code for this object.
no setterinherited
leading MNode?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing MNode?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited