MGauge class

Circular gauge / ring progress indicator.

Inheritance

Constructors

MGauge({required Object value, double max = 100, MColor? trackColor, MColor? fillColor, double lineWidth = 6})
const

Properties

fillColor MColor?
final
hashCode int
The hash code for this object.
no setterinherited
lineWidth double
final
max double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackColor MColor?
final
value Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited