MIcon class

Icon widget. iOS uses an SF Symbol name; Android uses a drawable resource name. At least one should be provided.

Inheritance

Constructors

MIcon({String? sfSymbol, String? androidDrawable, double size = 24, MColor? color})
const

Properties

androidDrawable String?
final
color MColor?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sfSymbol String?
final
size double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited