MInsets class

Constructors

MInsets.all(double value)
const
MInsets.only({double left = 0, double top = 0, double right = 0, double bottom = 0})
const
MInsets.symmetric({double vertical = 0, double horizontal = 0})
const

Properties

bottom double
final
hashCode int
The hash code for this object.
no setterinherited
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited