MLinearGradient class

Inheritance

Constructors

MLinearGradient({required List<MColor> colors, List<double>? stops, double angle = 0})
const

Properties

angle double
Direction in degrees. 0 = left→right, 90 = top→bottom.
final
colors List<MColor>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stops List<double>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited