MProgressBar class

Inheritance

Constructors

MProgressBar({required Object value, double max = 100.0, MColor color = const MColor.hex("#4444FF")})
const

Properties

color MColor
final
hashCode int
The hash code for this object.
no setterinherited
max double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited