MShadow class

Drop shadow for a container.

Constructors

MShadow({MColor? color, double blur = 8, double dx = 0, double dy = 2})
const

Properties

blur double
final
color MColor?
final
dx double
final
dy double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited