MTextStyle class
Constructors
- MTextStyle({double? size, MColor? color, double? opacity, bool? bold, MFontWeight? weight, bool? italic, MTextRole? role, MTextStyle? baseStyle})
-
const
Properties
- baseStyle → MTextStyle?
-
A style to inherit from — anything set here is overridden by the fields
on this instance.
final
- bold → bool?
-
final
- color → MColor?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- italic → bool?
-
Renders italic.
final
- opacity → double?
-
final
- role → MTextRole?
-
Semantic type role. An explicit size overrides it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double?
-
final
- weight → MFontWeight?
-
Font weight. Takes precedence over bold when both are set.
final
Methods
-
copyWith(
{double? size, MColor? color, double? opacity, bool? bold, MFontWeight? weight, bool? italic, MTextRole? role}) → MTextStyle - A copy with the given fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited