MTimer class

Timer widget.

Inheritance

Constructors

MTimer({required DateTime target, bool countUp = false, MTextStyle style = const MTextStyle()})
const

Properties

countUp bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style MTextStyle
final
target DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited