MVisibility class
Conditional visibility.
Constructors
- MVisibility({required MBind bind, required MNode child, MNode? replacement})
-
const
Properties
- bind → MBind
-
final
- child → MNode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- replacement → MNode?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited