MosaicDefinition class

The final definition of a widget.

Constructors

MosaicDefinition({required String name, required MNode root, MNode? compactRoot, Duration? updateInterval, int width = 2, int height = 2, String? previewImage, MResizeMode resizeMode = MResizeMode.none, List<MParam> params = const []})
const

Properties

compactRoot MNode?
An alternate tree for the smallest sizes — systemSmall on iOS, and a narrow tile on Android.
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
name String
final
params List<MParam>
User-editable parameters exposed via the OS configuration UI. Each param's chosen value is available to root via MBind(param.key). Defaults to no params.
final
previewImage String?
final
resizeMode MResizeMode
final
root MNode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateInterval Duration?
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited