MContainer class
Container widget (background, radius).
Constructors
Properties
- background → MColor?
-
final
- border → MBorder?
-
final
- child → MNode
-
final
- corners → MRadius?
-
Per-corner radius. When non-null, takes precedence over the scalar
radius field for rounding.
final
- gradient → MGradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- margin → MInsets?
-
final
- padding → MInsets?
-
Space between the container's edge and its child, inside the
background and border — the same meaning as Flutter's
Container(padding:). Saves wrapping the child in an MPadding.final - radius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → MShadow?
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited