MImage class
Image widget.
Constructors
- MImage(MImageSource source, {MBoxFit fit = MBoxFit.cover, double? radius, bool circle = false, MAccentedRendering? accentedMode})
-
const
Properties
- accentedMode → MAccentedRendering?
-
How this image renders when widgets are tinted (iOS 18+). Leave null to
accept the system default, which tints the image.
final
- circle → bool
-
Clips to a circle — the usual way to get an avatar.
final
- fit → MBoxFit
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- radius → double?
-
Corner radius in logical pixels. Ignored when circle is true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → MImageSource
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited