accentedMode property
How this image renders when widgets are tinted (iOS 18+). Leave null to accept the system default, which tints the image.
Implementation
final MAccentedRendering? accentedMode;
How this image renders when widgets are tinted (iOS 18+). Leave null to accept the system default, which tints the image.
final MAccentedRendering? accentedMode;