MText class
Text widget for home widgets.
Constructors
- MText(Object text, {MTextStyle style = const MTextStyle(), MFormat? format, String? currencyCode, int? maxLines, MTextAlign? align, MContentTransition? contentTransition})
-
const
Properties
- align → MTextAlign?
-
final
- contentTransition → MContentTransition?
-
How the value animates when it changes. iOS 17+ only — see
MContentTransition.
final
- currencyCode → String?
-
ISO 4217 code for MFormat.currency, e.g.
'USD'.final - format → MFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → MTextStyle
-
final
- text → Object
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited