MTextStyle class

Styling types

Constructors

MTextStyle({double? size, MColor? color, double? opacity, bool? bold})
const

Properties

bold bool?
final
color MColor?
final
hashCode int
The hash code for this object.
no setterinherited
opacity double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited